homology.dim0.mkforestDBL — GDA Toolbox v1.0 Manual

# homology.dim0.mkforestDBL

`homology.dim0.` `mkforestDBL`()

  Make inclusion tree and parentage linked lists by walking across This method is for `np.float64` arrays (for indexing speed). open/closed parentheses.

  Parameters: | begins : `np.ndarray` The lower heights of a persistence bar. closes : `np.ndarray` The upper heights of a persistence bar. idents : `np.ndarray` The index of a Pandas DataFrame, for identifying locations
  Returns: | forest : `collections.defaultdict` forest_parents : dict

#### Previous topic

homology.dim0.all_roots

#### Next topic

homology.dim0.unionfind